#[non_exhaustive]pub struct AssociateResourcesToSubscriptionOutput {
pub subscription: Option<Subscription>,
pub e_tag: String,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.subscription: Option<Subscription>The details of the subscription with the newly added resources.
e_tag: StringThe updated entity tag for concurrency control.
Implementations
Sourceimpl AssociateResourcesToSubscriptionOutput
impl AssociateResourcesToSubscriptionOutput
Sourcepub fn subscription(&self) -> Option<&Subscription>
pub fn subscription(&self) -> Option<&Subscription>
The details of the subscription with the newly added resources.
Sourceimpl AssociateResourcesToSubscriptionOutput
impl AssociateResourcesToSubscriptionOutput
Sourcepub fn builder() -> AssociateResourcesToSubscriptionOutputBuilder
pub fn builder() -> AssociateResourcesToSubscriptionOutputBuilder
Creates a new builder-style object to manufacture AssociateResourcesToSubscriptionOutput.