CreateSubscriptionInputBuilder

Struct CreateSubscriptionInputBuilder 

#[non_exhaustive]
pub struct CreateSubscriptionInputBuilder { /* private fields */ }
A builder for CreateSubscriptionInput.

Implementations

Source

impl CreateSubscriptionInputBuilder

pub fn plan_family(self, input: impl Into<String>) -> Self

The pricing plan family to subscribe to, such as CloudFront.

This field is required.
pub fn set_plan_family(self, input: Option<String>) -> Self

The pricing plan family to subscribe to, such as CloudFront.

pub fn get_plan_family(&self) -> &Option<String>

The pricing plan family to subscribe to, such as CloudFront.

pub fn plan_tier(self, input: impl Into<String>) -> Self

The tier level for the subscription, such as FREE, PRO, BUSINESS, or PREMIUM.

This field is required.
pub fn set_plan_tier(self, input: Option<String>) -> Self

The tier level for the subscription, such as FREE, PRO, BUSINESS, or PREMIUM.

pub fn get_plan_tier(&self) -> &Option<String>

The tier level for the subscription, such as FREE, PRO, BUSINESS, or PREMIUM.

pub fn usage_level(self, input: impl Into<String>) -> Self

The usage level within the plan tier. Specify DEFAULT for the base configuration, or a higher level if your plan tier supports it.

pub fn set_usage_level(self, input: Option<String>) -> Self

The usage level within the plan tier. Specify DEFAULT for the base configuration, or a higher level if your plan tier supports it.

pub fn get_usage_level(&self) -> &Option<String>

The usage level within the plan tier. Specify DEFAULT for the base configuration, or a higher level if your plan tier supports it.

pub fn resource_arns(self, input: impl Into<String>) -> Self

Appends an item to resource_arns.

To override the contents of this collection use set_resource_arns.

The ARNs of the AWS resources to include in the subscription. Specify one or more supported resources.

For subscriptions in the CloudFront plan family, the resources must include exactly one Amazon CloudFront distribution and exactly one AWS WAF web ACL. You can also include other supported resources, such as Amazon Route 53 hosted zones and CloudFront KeyValueStores.

pub fn set_resource_arns(self, input: Option<Vec<String>>) -> Self

The ARNs of the AWS resources to include in the subscription. Specify one or more supported resources.

For subscriptions in the CloudFront plan family, the resources must include exactly one Amazon CloudFront distribution and exactly one AWS WAF web ACL. You can also include other supported resources, such as Amazon Route 53 hosted zones and CloudFront KeyValueStores.

pub fn get_resource_arns(&self) -> &Option<Vec<String>>

The ARNs of the AWS resources to include in the subscription. Specify one or more supported resources.

For subscriptions in the CloudFront plan family, the resources must include exactly one Amazon CloudFront distribution and exactly one AWS WAF web ACL. You can also include other supported resources, such as Amazon Route 53 hosted zones and CloudFront KeyValueStores.

pub fn approval_mode(self, input: ApprovalMode) -> Self

Determines whether the subscription requires explicit approval before billing starts. Set to MANUAL to require a separate ApprovePaidSubscription call, or IMMEDIATE to activate the subscription right away. Defaults to IMMEDIATE if not specified.

pub fn set_approval_mode(self, input: Option<ApprovalMode>) -> Self

Determines whether the subscription requires explicit approval before billing starts. Set to MANUAL to require a separate ApprovePaidSubscription call, or IMMEDIATE to activate the subscription right away. Defaults to IMMEDIATE if not specified.

pub fn get_approval_mode(&self) -> &Option<ApprovalMode>

Determines whether the subscription requires explicit approval before billing starts. Set to MANUAL to require a separate ApprovePaidSubscription call, or IMMEDIATE to activate the subscription right away. Defaults to IMMEDIATE if not specified.

pub fn client_token(self, input: impl Into<String>) -> Self

A unique, case-sensitive identifier that you provide to ensure that the request is handled only once. If you send the same request with the same client token, the API returns the original response without creating a duplicate subscription.

pub fn set_client_token(self, input: Option<String>) -> Self

A unique, case-sensitive identifier that you provide to ensure that the request is handled only once. If you send the same request with the same client token, the API returns the original response without creating a duplicate subscription.

pub fn get_client_token(&self) -> &Option<String>

A unique, case-sensitive identifier that you provide to ensure that the request is handled only once. If you send the same request with the same client token, the API returns the original response without creating a duplicate subscription.

pub fn build(self) -> Result<CreateSubscriptionInput, BuildError>

Consumes the builder and constructs a CreateSubscriptionInput.

Source

impl CreateSubscriptionInputBuilder

pub async fn send_with( self, client: &Client, ) -> Result<CreateSubscriptionOutput, SdkError<CreateSubscriptionError, HttpResponse>>

Sends a request with this input using the given client.