#[non_exhaustive]pub struct CreateSubscriptionInput {
pub plan_family: Option<String>,
pub plan_tier: Option<String>,
pub usage_level: Option<String>,
pub resource_arns: Option<Vec<String>>,
pub approval_mode: Option<ApprovalMode>,
pub client_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.plan_family: Option<String>The pricing plan family to subscribe to, such as CloudFront.
plan_tier: Option<String>The tier level for the subscription, such as FREE, PRO, BUSINESS, or PREMIUM.
usage_level: Option<String>The usage level within the plan tier. Specify DEFAULT for the base configuration, or a higher level if your plan tier supports it.
resource_arns: Option<Vec<String>>The ARNs of the AWS resources to include in the subscription. Specify one or more supported resources.
For subscriptions in the CloudFront plan family, the resources must include exactly one Amazon CloudFront distribution and exactly one AWS WAF web ACL. You can also include other supported resources, such as Amazon Route 53 hosted zones and CloudFront KeyValueStores.
approval_mode: Option<ApprovalMode>Determines whether the subscription requires explicit approval before billing starts. Set to MANUAL to require a separate ApprovePaidSubscription call, or IMMEDIATE to activate the subscription right away. Defaults to IMMEDIATE if not specified.
client_token: Option<String>A unique, case-sensitive identifier that you provide to ensure that the request is handled only once. If you send the same request with the same client token, the API returns the original response without creating a duplicate subscription.
Implementations
Sourceimpl CreateSubscriptionInput
impl CreateSubscriptionInput
Sourcepub fn plan_family(&self) -> Option<&str>
pub fn plan_family(&self) -> Option<&str>
The pricing plan family to subscribe to, such as CloudFront.
Sourcepub fn plan_tier(&self) -> Option<&str>
pub fn plan_tier(&self) -> Option<&str>
The tier level for the subscription, such as FREE, PRO, BUSINESS, or PREMIUM.
Sourcepub fn usage_level(&self) -> Option<&str>
pub fn usage_level(&self) -> Option<&str>
The usage level within the plan tier. Specify DEFAULT for the base configuration, or a higher level if your plan tier supports it.
Sourcepub fn resource_arns(&self) -> &[String]
pub fn resource_arns(&self) -> &[String]
The ARNs of the AWS resources to include in the subscription. Specify one or more supported resources.
For subscriptions in the CloudFront plan family, the resources must include exactly one Amazon CloudFront distribution and exactly one AWS WAF web ACL. You can also include other supported resources, such as Amazon Route 53 hosted zones and CloudFront KeyValueStores.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .resource_arns.is_none().
Sourcepub fn approval_mode(&self) -> Option<&ApprovalMode>
pub fn approval_mode(&self) -> Option<&ApprovalMode>
Determines whether the subscription requires explicit approval before billing starts. Set to MANUAL to require a separate ApprovePaidSubscription call, or IMMEDIATE to activate the subscription right away. Defaults to IMMEDIATE if not specified.
Sourcepub fn client_token(&self) -> Option<&str>
pub fn client_token(&self) -> Option<&str>
A unique, case-sensitive identifier that you provide to ensure that the request is handled only once. If you send the same request with the same client token, the API returns the original response without creating a duplicate subscription.
Sourceimpl CreateSubscriptionInput
impl CreateSubscriptionInput
Sourcepub fn builder() -> CreateSubscriptionInputBuilder
pub fn builder() -> CreateSubscriptionInputBuilder
Creates a new builder-style object to manufacture CreateSubscriptionInput.