#[non_exhaustive]pub struct ListSubscriptionsOutputBuilder { /* private fields */ }Expand description
A builder for ListSubscriptionsOutput.
Implementations
Sourceimpl ListSubscriptionsOutputBuilder
impl ListSubscriptionsOutputBuilder
Sourcepub fn subscription_summaries(self, input: SubscriptionSummary) -> Self
pub fn subscription_summaries(self, input: SubscriptionSummary) -> Self
Appends an item to subscription_summaries.
To override the contents of this collection use set_subscription_summaries.
The list of subscription summaries for the calling account.
Sourcepub fn set_subscription_summaries(
self,
input: Option<Vec<SubscriptionSummary>>,
) -> Self
pub fn set_subscription_summaries( self, input: Option<Vec<SubscriptionSummary>>, ) -> Self
The list of subscription summaries for the calling account.
Sourcepub fn get_subscription_summaries(&self) -> &Option<Vec<SubscriptionSummary>>
pub fn get_subscription_summaries(&self) -> &Option<Vec<SubscriptionSummary>>
The list of subscription summaries for the calling account.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A token that indicates there are more results available. Pass this value in a subsequent ListSubscriptions request to retrieve the next page of results.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A token that indicates there are more results available. Pass this value in a subsequent ListSubscriptions request to retrieve the next page of results.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A token that indicates there are more results available. Pass this value in a subsequent ListSubscriptions request to retrieve the next page of results.
Sourcepub fn build(self) -> Result<ListSubscriptionsOutput, BuildError>
pub fn build(self) -> Result<ListSubscriptionsOutput, BuildError>
Consumes the builder and constructs a ListSubscriptionsOutput.
This method will fail if any of the following fields are not set: