pub struct Client { /* private fields */ }Expand description
Client for PricingPlanManager
Client for invoking operations on PricingPlanManager. Each operation on PricingPlanManager is a method on this
this struct. .send() MUST be invoked on the generated operations to dispatch the request to the service.
Constructing a Client
A Config is required to construct a client. For most use cases, the aws-config
crate should be used to automatically resolve this config using
aws_config::load_from_env(), since this will resolve an SdkConfig which can be shared
across multiple different AWS SDK clients. This config resolution process can be customized
by calling aws_config::from_env() instead, which returns a ConfigLoader that uses
the builder pattern to customize the default config.
In the simplest case, creating a client looks as follows:
let config = aws_config::load_from_env().await;
let client = aws_sdk_pricingplanmanager::Client::new(&config);Occasionally, SDKs may have additional service-specific values that can be set on the Config that
is absent from SdkConfig, or slightly different settings for a specific client may be desired.
The Builder struct implements From<&SdkConfig>, so setting these specific settings can be
done as follows:
let sdk_config = ::aws_config::load_from_env().await;
let config = aws_sdk_pricingplanmanager::config::Builder::from(&sdk_config)
.some_service_specific_setting("value")
.build();See the aws-config docs and Config for more information on customizing configuration.
Note: Client construction is expensive due to connection thread pool initialization, and should be done once at application start-up.
Using the Client
A client has a function for every operation that can be performed by the service.
For example, the ApprovePaidSubscription operation has
a Client::approve_paid_subscription, function which returns a builder for that operation.
The fluent builder ultimately has a send() function that returns an async future that
returns a result, as illustrated below:
let result = client.approve_paid_subscription()
.arn("example")
.send()
.await;The underlying HTTP requests that get made by this can be modified with the customize_operation
function on the fluent builder. See the customize module for more
information.
Implementations
Sourceimpl Client
impl Client
Sourcepub fn approve_paid_subscription(&self) -> ApprovePaidSubscriptionFluentBuilder
pub fn approve_paid_subscription(&self) -> ApprovePaidSubscriptionFluentBuilder
Constructs a fluent builder for the ApprovePaidSubscription operation.
- The fluent builder is configurable:
arn(impl Into<String>)/set_arn(Option<String>):
required: trueThe ARN of the subscription to approve.
if_match(impl Into<String>)/set_if_match(Option<String>):
required: trueThe
ETagvalue from a previousGetSubscriptionorListSubscriptionsresponse. This ensures you are approving the expected version of the subscription.client_token(impl Into<String>)/set_client_token(Option<String>):
required: falseA unique, case-sensitive identifier that you provide to ensure the request is handled only once.
- On success, responds with
ApprovePaidSubscriptionOutputwith field(s):subscription(Option<Subscription>):The details of the approved subscription.
e_tag(String):The updated entity tag for concurrency control.
- On failure, responds with
SdkError<ApprovePaidSubscriptionError>
Sourceimpl Client
impl Client
Sourcepub fn associate_resources_to_subscription(
&self,
) -> AssociateResourcesToSubscriptionFluentBuilder
pub fn associate_resources_to_subscription( &self, ) -> AssociateResourcesToSubscriptionFluentBuilder
Constructs a fluent builder for the AssociateResourcesToSubscription operation.
- The fluent builder is configurable:
arn(impl Into<String>)/set_arn(Option<String>):
required: trueThe ARN of the subscription to add resources to.
resource_arns(impl Into<String>)/set_resource_arns(Option<Vec::<String>>):
required: trueThe ARNs of the resources to add to the subscription.
if_match(impl Into<String>)/set_if_match(Option<String>):
required: trueThe
ETagvalue from a previousGetSubscriptionorListSubscriptionsresponse.client_token(impl Into<String>)/set_client_token(Option<String>):
required: falseA unique, case-sensitive identifier that you provide to ensure the request is handled only once.
- On success, responds with
AssociateResourcesToSubscriptionOutputwith field(s):subscription(Option<Subscription>):The details of the subscription with the newly added resources.
e_tag(String):The updated entity tag for concurrency control.
- On failure, responds with
SdkError<AssociateResourcesToSubscriptionError>
Sourceimpl Client
impl Client
Sourcepub fn cancel_subscription(&self) -> CancelSubscriptionFluentBuilder
pub fn cancel_subscription(&self) -> CancelSubscriptionFluentBuilder
Constructs a fluent builder for the CancelSubscription operation.
- The fluent builder is configurable:
arn(impl Into<String>)/set_arn(Option<String>):
required: trueThe ARN of the subscription to cancel.
if_match(impl Into<String>)/set_if_match(Option<String>):
required: trueThe
ETagvalue from a previousGetSubscriptionorListSubscriptionsresponse.client_token(impl Into<String>)/set_client_token(Option<String>):
required: falseA unique, case-sensitive identifier that you provide to ensure the request is handled only once.
- On success, responds with
CancelSubscriptionOutputwith field(s):subscription(Option<Subscription>):The details of the subscription with the pending cancellation. For active subscriptions, a
scheduledChangeof typeCANCELLATIONis included.e_tag(String):The updated entity tag for concurrency control.
- On failure, responds with
SdkError<CancelSubscriptionError>
Sourceimpl Client
impl Client
Sourcepub fn cancel_subscription_change(
&self,
) -> CancelSubscriptionChangeFluentBuilder
pub fn cancel_subscription_change( &self, ) -> CancelSubscriptionChangeFluentBuilder
Constructs a fluent builder for the CancelSubscriptionChange operation.
- The fluent builder is configurable:
arn(impl Into<String>)/set_arn(Option<String>):
required: trueThe ARN of the subscription whose pending change you want to cancel.
if_match(impl Into<String>)/set_if_match(Option<String>):
required: trueThe
ETagvalue from a previousGetSubscriptionorListSubscriptionsresponse.client_token(impl Into<String>)/set_client_token(Option<String>):
required: falseA unique, case-sensitive identifier that you provide to ensure the request is handled only once.
- On success, responds with
CancelSubscriptionChangeOutputwith field(s):subscription(Option<Subscription>):The details of the subscription with the pending change removed.
e_tag(String):The updated entity tag for concurrency control.
- On failure, responds with
SdkError<CancelSubscriptionChangeError>
Sourceimpl Client
impl Client
Sourcepub fn create_subscription(&self) -> CreateSubscriptionFluentBuilder
pub fn create_subscription(&self) -> CreateSubscriptionFluentBuilder
Constructs a fluent builder for the CreateSubscription operation.
- The fluent builder is configurable:
plan_family(impl Into<String>)/set_plan_family(Option<String>):
required: trueThe pricing plan family to subscribe to, such as
CloudFront.plan_tier(impl Into<String>)/set_plan_tier(Option<String>):
required: trueThe tier level for the subscription, such as
FREE,PRO,BUSINESS, orPREMIUM.usage_level(impl Into<String>)/set_usage_level(Option<String>):
required: falseThe usage level within the plan tier. Specify
DEFAULTfor the base configuration, or a higher level if your plan tier supports it.resource_arns(impl Into<String>)/set_resource_arns(Option<Vec::<String>>):
required: trueThe ARNs of the AWS resources to include in the subscription. Specify one or more supported resources.
For subscriptions in the CloudFront plan family, the resources must include exactly one Amazon CloudFront distribution and exactly one AWS WAF web ACL. You can also include other supported resources, such as Amazon Route 53 hosted zones and CloudFront KeyValueStores.
approval_mode(ApprovalMode)/set_approval_mode(Option<ApprovalMode>):
required: falseDetermines whether the subscription requires explicit approval before billing starts. Set to
MANUALto require a separateApprovePaidSubscriptioncall, orIMMEDIATEto activate the subscription right away. Defaults toIMMEDIATEif not specified.client_token(impl Into<String>)/set_client_token(Option<String>):
required: falseA unique, case-sensitive identifier that you provide to ensure that the request is handled only once. If you send the same request with the same client token, the API returns the original response without creating a duplicate subscription.
- On success, responds with
CreateSubscriptionOutputwith field(s):subscription(Option<Subscription>):The details of the newly created subscription.
e_tag(String):The entity tag for concurrency control. Use this value in the
If-Matchheader for subsequent operations on this subscription.
- On failure, responds with
SdkError<CreateSubscriptionError>
Sourceimpl Client
impl Client
Sourcepub fn disassociate_resources_from_subscription(
&self,
) -> DisassociateResourcesFromSubscriptionFluentBuilder
pub fn disassociate_resources_from_subscription( &self, ) -> DisassociateResourcesFromSubscriptionFluentBuilder
Constructs a fluent builder for the DisassociateResourcesFromSubscription operation.
- The fluent builder is configurable:
arn(impl Into<String>)/set_arn(Option<String>):
required: trueThe ARN of the subscription to remove resources from.
resource_arns(impl Into<String>)/set_resource_arns(Option<Vec::<String>>):
required: trueThe ARNs of the resources to remove from the subscription. For subscriptions in the CloudFront plan family, you cannot remove the required CloudFront distribution or WAF web ACL.
if_match(impl Into<String>)/set_if_match(Option<String>):
required: trueThe
ETagvalue from a previousGetSubscriptionorListSubscriptionsresponse.client_token(impl Into<String>)/set_client_token(Option<String>):
required: falseA unique, case-sensitive identifier that you provide to ensure the request is handled only once.
- On success, responds with
DisassociateResourcesFromSubscriptionOutputwith field(s):subscription(Option<Subscription>):The details of the subscription with the specified resources removed.
e_tag(String):The updated entity tag for concurrency control.
- On failure, responds with
SdkError<DisassociateResourcesFromSubscriptionError>
Sourceimpl Client
impl Client
Sourcepub fn get_subscription(&self) -> GetSubscriptionFluentBuilder
pub fn get_subscription(&self) -> GetSubscriptionFluentBuilder
Constructs a fluent builder for the GetSubscription operation.
- The fluent builder is configurable:
arn(impl Into<String>)/set_arn(Option<String>):
required: trueThe ARN of the subscription to retrieve.
- On success, responds with
GetSubscriptionOutputwith field(s):subscription(Option<Subscription>):The details of the requested subscription.
e_tag(String):The entity tag for concurrency control. Use this value in the
If-Matchheader for subsequent operations on this subscription.
- On failure, responds with
SdkError<GetSubscriptionError>
Sourceimpl Client
impl Client
Sourcepub fn list_subscriptions(&self) -> ListSubscriptionsFluentBuilder
pub fn list_subscriptions(&self) -> ListSubscriptionsFluentBuilder
Constructs a fluent builder for the ListSubscriptions operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
next_token(impl Into<String>)/set_next_token(Option<String>):
required: falseA token from a previous
ListSubscriptionsresponse. If the response included anextToken, there are more results available. Pass this value to retrieve the next page of results.
- On success, responds with
ListSubscriptionsOutputwith field(s):subscription_summaries(Vec::<SubscriptionSummary>):The list of subscription summaries for the calling account.
next_token(Option<String>):A token that indicates there are more results available. Pass this value in a subsequent
ListSubscriptionsrequest to retrieve the next page of results.
- On failure, responds with
SdkError<ListSubscriptionsError>
Sourceimpl Client
impl Client
Sourcepub fn update_subscription(&self) -> UpdateSubscriptionFluentBuilder
pub fn update_subscription(&self) -> UpdateSubscriptionFluentBuilder
Constructs a fluent builder for the UpdateSubscription operation.
- The fluent builder is configurable:
arn(impl Into<String>)/set_arn(Option<String>):
required: trueThe ARN of the subscription to update.
plan_tier(impl Into<String>)/set_plan_tier(Option<String>):
required: trueThe new tier level for the subscription.
usage_level(impl Into<String>)/set_usage_level(Option<String>):
required: falseThe usage level within the plan tier. Specify
DEFAULTfor the base configuration. If omitted, the usage level is reset to the default.if_match(impl Into<String>)/set_if_match(Option<String>):
required: trueThe
ETagvalue from a previousGetSubscriptionorListSubscriptionsresponse. This ensures you are updating the expected version of the subscription.client_token(impl Into<String>)/set_client_token(Option<String>):
required: falseA unique, case-sensitive identifier that you provide to ensure the request is handled only once.
- On success, responds with
UpdateSubscriptionOutputwith field(s):subscription(Option<Subscription>):The details of the updated subscription. For downgrades, the current tier remains unchanged and a
scheduledChangeindicates the pending change.e_tag(String):The updated entity tag for concurrency control.
- On failure, responds with
SdkError<UpdateSubscriptionError>
Sourceimpl Client
impl Client
Sourcepub fn from_conf(conf: Config) -> Self
pub fn from_conf(conf: Config) -> Self
Creates a new client from the service Config.
Panics
This method will panic in the following cases:
- Retries or timeouts are enabled without a
sleep_implconfigured. - Identity caching is enabled without a
sleep_implandtime_sourceconfigured. - No
behavior_versionis provided.
The panic message for each of these will have instructions on how to resolve them.
Sourceimpl Client
impl Client
Sourcepub fn new(sdk_config: &SdkConfig) -> Self
pub fn new(sdk_config: &SdkConfig) -> Self
Creates a new client from an SDK Config.
Panics
- This method will panic if the
sdk_configis missing an async sleep implementation. If you experience this panic, set thesleep_implon the Config passed into this function to fix it. - This method will panic if the
sdk_configis missing an HTTP connector. If you experience this panic, set thehttp_connectoron the Config passed into this function to fix it. - This method will panic if no
BehaviorVersionis provided. If you experience this panic, setbehavior_versionon the Config or enable thebehavior-version-latestCargo feature.